@@ -5,10 +5,9 @@
 #' @details This function is intended to be called internally with no
 #' arguments.  It will use the directory set by the system environmental
 #' variable CONTENTID_HOME, if set.  Otherwise, it will use the default
-#' location returned by [rappdirs::user_data_dir] for the application,
+#' location returned by [tools::R_user_dir] for the application,
 #' `contentid`.  Unlike rappdirs function, this function will also 
 #' create the directory if it does not yet exist.
-#' @importFrom rappdirs user_data_dir
 #' @importFrom fs dir_create dir_exists
 #' @export
 #' @examples 
@@ -24,7 +23,7 @@
 #' content_dir(tempdir())
 content_dir <- function(dir = Sys.getenv(
   "CONTENTID_HOME",
-  rappdirs::user_data_dir("contentid")
+  tools::R_user_dir("contentid")
 )) {
   if (!fs::dir_exists(dir)) fs::dir_create(dir)
   dir
