@@ -47,7 +47,8 @@ resolve <- function(id,
                     dir = content_dir(),
                     ...) {
   
-  df <- query_sources(id, registries, cols=c("identifier", "source", "date"), ...)
+  df <- query_sources(id, registries, cols=c("identifier", "source", "date"), 
+                      all = FALSE, ...)
   
   if(is.null(df) || nrow(df) == 0){
     warning(paste("No sources found for", id))
