@@ -30,7 +30,11 @@ download_resource <- function(x) {
 
 ## These should be much more general!
 add_prefix <- function(x) paste0("hash://sha256/", x)
-strip_prefix <- function(x) gsub("^hash://sha256/", "", x)
+strip_prefix <- function(x) gsub(hashuri_regex, "\\2", x)
+extract_algo <- function(x) gsub(hashuri_regex, "\\1", x)
+
+
+
 is_url <- function(x) grepl("^((http|ftp)s?|sftp)://", x)
 
 
